@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2016-02-04'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2016-02-27'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,6 +14,7 @@ use File::Which;
 use Filename::Backup qw(check_backup_filename);
 use Module::CoreList::More;
 use Scalar::Util 'looks_like_number';
+use Sort::Sub qw(prereq_ala_perlancar);
 use Version::Util qw(version_gt version_ne);
 
 our %SPEC;
@@ -349,6 +350,8 @@ sub lint_prereqs {
         }
     }
 
+    @errs = sort {prereq_ala_perlancar($a->{module}, $b->{module})} @errs;
+
     my $resmeta = {
         "cmdline.exit_code" => @errs ? 500-300:0,
         "table.fields" => [qw/module req_v is_core error remedy/],
@@ -371,7 +374,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.34 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-02-04.
+This document describes version 0.35 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-02-27.
 
 =head1 SYNOPSIS
 
